<?php

namespace App\Http\Controllers;

use Illuminate\Support\Facades\Storage;
use App\Models\Testimonial;

use Illuminate\Http\Request;

class TestimonialController extends Controller
{
    public function store(Request $request){
   
    $request->validate([
    'name' => 'required|string',
    'comment' => 'required|string',
    'image' => 'required|file|mimes:jpeg,png,gif,webp|max:2048',
    ]);
    
    try {
        $testimonial = new Testimonial();
        $testimonial->name = $request->name;
        $testimonial->comment = $request->comment;
    
        if ($request->has('image')) {
            $uploadedFile = $request->file('image');
        
            // Store the file using Laravel's storage system
            $filePath = $uploadedFile->store('testimonials');
            
            // Generate the full URL, including the base URL and the path returned by Storage::url
            $testimonial->image_path = 'https://datland.dev.digtalsdesigns.com/'.Storage::url('app/'.$filePath);
        }

    
        $result = $testimonial->save();
    
        if ($result) {
            return response(['data' => $testimonial]);
        } else {
            return response(['error' => 'testimonial Could Not Be Stored']);
        }
    } catch (\Exception $e) {
        // Log the exception for further investigation
        \Log::error('Exception during testimonial creation: ' . $e->getMessage());
        return response(['error' => 'Internal Server Error'], 500);
    }

            

    }

    public function update(Request $request,$id){
        $testimonial = Testimonial::find($id);
        $testimonial->name = $request->name;
        $testimonial->comment = $request->comment;
        if ($request->has('image')) {
            $uploadedFile = $request->file('image');
        
            // Store the file using Laravel's storage system
            $filePath = $uploadedFile->store('testimonials');
            
            // Generate the full URL, including the base URL and the path returned by Storage::url
            $testimonial->image_path = 'https://datland.dev.digtalsdesigns.com/'.Storage::url('app/'.$filePath);
        }
        $result = $testimonial->save();
        if($result){
            return response([
                'status'=>200,
                'error'=>''
                ]);
        }else{
            return response([
                'status'=>404,
                'error'=>'testimonial Could Not Be Updated'
            ]);
        }
    }

    public function show(){
        $testimonials = Testimonial::all();
        return response($testimonials);
    }

    public function delete($id){
        $result = Testimonial::where('id',$id)->delete();
        if($result){
            return response(['status'=>'200']);
        }else{
            return response(['status'=>'404']);
        }

    }

    public function testimonialDetails($id){
        $result = Testimonial::where('id',$id)->first();
        if($result){
            return response([
                'data'=>$result,
                'status'=>'200'
            ]);
        }else{
            return response(['status'=>'404']);
        }

    }
    
    public function searchedtestimonialDetails(Request $request){
        $result = Testimonial::where('name',$request->searched)->first();
        if($result){
            return response([
                'data'=>$result,
                'status'=>'200'
            ]);
        }else{
            return response(['status'=>'404']);
        }

    }
    

}
